@@ -43,42 +43,43 @@ class TRLabel;
 class KModemLightsApplet : public KPanelApplet
 {
   Q_OBJECT
-    
- public:
-
+  
+public:
+  
   KModemLightsApplet(const QString& configFile, Type t = Normal, 
-		    int actions = 0, QWidget *parent = 0, 
-		    const char *name = 0);
+		     int actions = 0, QWidget *parent = 0, 
+		     const char *name = 0);
   ~KModemLightsApplet();
-
+  
   int widthForHeight(int height) const;
   int heightForWidth(int width) const;
-
- public slots:
-
+  
+public slots:
+	      
   void dial(); 
-
- protected:
-
+  
+protected:
+  
   void mousePressEvent(QMouseEvent *);
-
- protected slots:
+  
+protected slots:
  
   void timerEvent(QTimerEvent *e);
   void about();
   void preferences();
-
+  
   virtual void resizeEvent(QResizeEvent *);  
-
- private:
-
+  
+private:
+  
   void readConfig();
-
+  
   void updateTimer();
   void updateLights(bool rx, bool tx);
   void updateGraph(unsigned int rx, unsigned int tx);
   void updateRx(int rx);
 
+  QFont fontForHeight(int widgetheight) const;
   void horizontalLayout(int height);
   void verticalLayout(int width);
 
@@ -103,6 +104,8 @@ class KModemLightsApplet : public KPanelApplet
   int updateFrequency;
   bool showRequesters;
   unsigned int graphMaxValue;
+  bool unlimitFontSize;
+  StatusButton::IconSize iconSize;
 
   Modem modem;
 
