@@ -18,21 +18,16 @@
  *
  */
 
-#include <qspinbox.h>
 #include <qlayout.h>
 #include <qwhatsthis.h>
-#include <qlineedit.h> 
 #include <qgroupbox.h>
 #include <qvgroupbox.h>
-#include <qcheckbox.h>
 #include <qhbox.h>
 #include <qgrid.h>
 
 #include <klocale.h>
 #include <kapplication.h>
 #include <ktabwidget.h>
-#include <kpushbutton.h>
-#include <kcolorbutton.h>
 
 #include "kmodemlights.h"
 #include "light.h"
@@ -121,10 +116,10 @@ QWidget *KModemLightsDlg::generateGeneral()
   QWidget *tab = new QWidget();
   QVBoxLayout *vbox = new QVBoxLayout(tab, 0, spacingHint());
 
-  // **** Behaviour
+  // **** Graph
   QVGroupBox *group = new QVGroupBox(i18n("General"), tab);
   vbox->addWidget(group);
- 
+
   // Frequency
   QHBox *hb = new QHBox(group);
   hb->setSpacing(spacingHint());
@@ -174,6 +169,34 @@ QWidget *KModemLightsDlg::generateGeneral()
   QWhatsThis::add(label, text);
   QWhatsThis::add(frequencyWidget, text);
 
+  // **** Apperance
+  group = new QVGroupBox(i18n("Apperance"), tab);
+  vbox->addWidget(group);
+ 
+  // unlimit Font Size
+  unlimitFontSizeWidget = new QCheckBox(i18n("Fontsize can grow beyound default"), group);
+  unlimitFontSizeWidget->setChecked(applet->unlimitFontSize);
+  text = i18n("<b>Limit the fontsize.</b>"
+	      "<p>Check this box if you want the size of the fonts "
+	      "in the widget to grow beyond the size of the default "
+	      "fixed-width-Font if the applets provides the space</p>");
+  QWhatsThis::add(unlimitFontSizeWidget, text);
+
+  // Icon
+  hb = new QHBox(group);
+  hb->setSpacing(spacingHint());
+  label = new QLabel(i18n("Size of Panel-Icons:"), hb);
+  iconSizeWidget = new QComboBox(false, hb);
+  iconSizeWidget->insertItem(i18n("small (12)"), 0);
+  iconSizeWidget->insertItem(i18n("medium (24)"), 1);
+  iconSizeWidget->insertItem(i18n("large (32)"), 2);
+  iconSizeWidget->setCurrentItem(applet->iconSize);
+  text = i18n("<b>Set the size of the Icons.</b>"
+	      "<p>Specify which size the icon in the applet should have, "
+	      "that shows the status of the connection.</p>");
+  QWhatsThis::add(label, text);
+  QWhatsThis::add(iconSizeWidget, text);
+
   // signals
   maxValueWidget->setDisabled(autoMaxWidget->isChecked());
   connect(autoMaxWidget, SIGNAL(toggled(bool)), 
@@ -250,8 +273,8 @@ QWidget *KModemLightsDlg::generateColor()
 
   graphBg->setColor(applet->graph->getColorBg());
 
-  statusAwait->setColor(applet->button->getColor(StatusButton::Wait));
-  statusOn->setColor(applet->button->getColor(StatusButton::On));
+  statusAwait->setColor(applet->button->color(StatusButton::Wait));
+  statusOn->setColor(applet->button->color(StatusButton::On));
 
   return tab;
 }
