@@ -29,29 +29,37 @@
 
 StatusButton::StatusButton(QWidget *parent, const char *name)
   : QPushButton(parent, name),
-    colorOn(0x00FF00), colorWait(0xFFFF00)
+    colorOn(0x00FF00), colorWait(0xFFFF00),
+    myIconSize(smallIcon)
 {
   // load all pixmaps
-  signOn.loadFromData(statusbutton_on, statusbutton_on_size);
-  signOff.loadFromData(statusbutton_off, statusbutton_off_size);
-  signWait.loadFromData(statusbutton_neither, statusbutton_neither_size);
-  signMask.loadFromData(statusbutton_mask, statusbutton_mask_size);
-  
+  signOn[0].loadFromData(statusbutton_on_12, statusbutton_on_12_size);
+  signOff[0].loadFromData(statusbutton_off_12, statusbutton_off_12_size);
+  signWait[0].loadFromData(statusbutton_neither_12, statusbutton_neither_12_size);
+  signMask[0].loadFromData(statusbutton_mask_12, statusbutton_mask_12_size);
+
+  signOn[1].loadFromData(statusbutton_on_24, statusbutton_on_24_size);
+  signOff[1].loadFromData(statusbutton_off_24, statusbutton_off_24_size);
+  signWait[1].loadFromData(statusbutton_neither_24, statusbutton_neither_24_size);
+  signMask[1].loadFromData(statusbutton_mask_24, statusbutton_mask_24_size);
+
+  signOn[2].loadFromData(statusbutton_on_32, statusbutton_on_32_size);
+  signOff[2].loadFromData(statusbutton_off_32, statusbutton_off_32_size);
+  signWait[2].loadFromData(statusbutton_neither_32, statusbutton_neither_32_size);
+  signMask[2].loadFromData(statusbutton_mask_32, statusbutton_mask_32_size);
+
   // generate the icons
-  generateIcon(on, signOn, colorOn);
-  generateIcon(wait, signWait, colorWait);
-  off = signOff;
+  generateIcon(on, signOn[myIconSize], colorOn);
+  generateIcon(wait, signWait[myIconSize], colorWait);
+  off = signOff[myIconSize];
 
   // set this consitently!
   setPixmap(off);
   myStatus = Off;
 }
 
-void StatusButton::setStatus(const Status s)
+void StatusButton::setIcon(Status s)
 {
-  if (s == myStatus)
-    return;
-
   switch(s) {
   case On:
     setPixmap(on);
@@ -63,8 +71,30 @@ void StatusButton::setStatus(const Status s)
     setPixmap(wait);
     break;
   }
+}
+
+void StatusButton::setStatus(const Status s)
+{
+  if (s == myStatus)
+    return;
+
+  setIcon(s);
   myStatus = s;
-  update();
+}
+
+void StatusButton::setIconSize(IconSize size)
+{
+  if (size == myIconSize)
+    return;
+
+  myIconSize = size;
+  
+  // generate the icons
+  generateIcon(on, signOn[myIconSize], colorOn);
+  generateIcon(wait, signWait[myIconSize], colorWait);
+  off = signOff[myIconSize];
+
+  setIcon(myStatus);
 }
 
 void StatusButton::setColor(const Status s, const QColor &c)
@@ -73,7 +103,7 @@ void StatusButton::setColor(const Status s, const QColor &c)
   case On:
     if (c != colorOn) {
       colorOn = c;
-      generateIcon(on, signOn, colorOn);
+      generateIcon(on, signOn[myIconSize], colorOn);
       if (s == myStatus) {
 	setPixmap(on);
 	update();
@@ -85,7 +115,7 @@ void StatusButton::setColor(const Status s, const QColor &c)
   case Wait:
     if (c != colorWait) {
       colorWait = c;
-      generateIcon(wait, signWait, colorWait);
+      generateIcon(wait, signWait[myIconSize], colorWait);
       if (s == myStatus) {
 	setPixmap(wait);
 	update();
@@ -95,7 +125,7 @@ void StatusButton::setColor(const Status s, const QColor &c)
   }
 }
 
-QColor StatusButton::getColor(const Status s) const
+QColor StatusButton::color(const Status s) const
 {
   switch(s) {
   case On:
@@ -115,7 +145,7 @@ QColor StatusButton::getColor(const Status s) const
 
 void StatusButton::generateIcon(QPixmap &px, const QPixmap &sign, const QColor &col)
 {
-  px = signMask;
+  px = signMask[myIconSize];
   QPainter p(&px);
   p.fillRect(0, 0, px.width()-1, px.height()-1, col);
   p.drawPixmap(0, 0, sign);
